@@ -30,7 +30,8 @@ config.funs.par <- function(fun = "", ...) {
 # Function get config.list
 get.config.list <- function(file, file.type = "json", json.file.debug = FALSE, ini.file.debug = FALSE, 
   yaml.file.debug = FALSE, toml.file.debug = FALSE, extra.list = list(), other.config = "", 
-  rcmd.parse = FALSE, ...) {
+  rcmd.parse = FALSE, bash.parse = FALSE, glue.parse = FALSE, glue.flag = "!!glue", 
+  ...) {
   if (file.type == "json") {
     readLines.par <- config.funs.par("readLines", ...)
     readLines.par <- config.list.merge(readLines.par, list(con = file))
@@ -116,7 +117,8 @@ get.config.list <- function(file, file.type = "json", json.file.debug = FALSE, i
   if (is.null(result)) {
     return(FALSE)
   } else {
-    config.list <- parse.extra(config.list, extra.list, other.config, rcmd.parse)
+    config.list <- parse.extra(config.list, extra.list, other.config, rcmd.parse, 
+      bash.parse, glue.parse, glue.flag)
     return(config.list)
   }
 }
